akhdefo_functions.Time_Series — akhdefo 2023 documentation

# akhdefo_functions.Time_Series

akhdefo_functions.Time_Series(stacked_raster_EW='', stacked_raster_NS='', velocity_points='', dates_name='', output_folder='', outputFilename='', rasteriz_mean_products=True, std=1, VEL_Scale='year')

  This program uses candiate velocity points from stackprep function and performs linear interpolation in time-domain to calibrate stacked velocity. Additionally produces corrected timeseries velocity(daily) in a shapefile. Inputs:

  stacked_raster_EW:

  stacked_raster_NS:

  velocity_points: Velcity Candidate points

  dates_name:text file include name of each date in format YYYYMMDD

  output_folder:

  outputFilename

  Returns:

  Time-series shape file of velocity and direction EW, NS, and 2D(resultant Velocity and direction)